@@ -22,6 +22,8 @@ from osxphotos.sqlite_utils import sqlite_columns
 from .push_results import PushResults
 from .sync_results import SyncResults
 
+EXPORT_REPORT_BATCH_SIZE = os.environ.get("OSXPHOTOS_EXPORT_REPORT_BATCH_SIZE", 100)
+
 __all__ = [
     "ExportReportWriterCSV",
     "ExportReportWriterJSON",
@@ -126,6 +128,8 @@ class ExportReportWriterCSV(ReportWriterABC):
         """Write results to the output file"""
         all_results = prepare_export_results_for_writing(export_results)
         for data in list(all_results.values()):
+            # uuid not yet supported in CSV report
+            data.pop("uuid", None)
             self._csv_writer.writerow(data)
         self._output_fh.flush()
 
@@ -187,6 +191,17 @@ class ExportReportWriterJSON(ReportWriterABC):
 class ExportReportWriterSQLite(ReportWriterABC):
     """Write sqlite report file for export data"""
 
+    # Number of records to buffer before committing to reduce commit overhead
+    BATCH_SIZE = EXPORT_REPORT_BATCH_SIZE
+
+    # SQL for batch inserts
+    _INSERT_SQL = (
+        "INSERT INTO report "
+        "(datetime, filename, exported, new, updated, skipped, exif_updated, touched, converted_to_jpeg, sidecar_xmp, sidecar_json, sidecar_exiftool, missing, error, exiftool_warning, exiftool_error, extended_attributes_written, extended_attributes_skipped, cleanup_deleted_file, cleanup_deleted_directory, exported_album, report_id, sidecar_user, sidecar_user_error, user_written, user_skipped, user_error, aae_written, aae_skipped) "  # noqa
+        "VALUES "
+        "(:datetime, :filename, :exported, :new, :updated, :skipped, :exif_updated, :touched, :converted_to_jpeg, :sidecar_xmp, :sidecar_json, :sidecar_exiftool, :missing, :error, :exiftool_warning, :exiftool_error, :extended_attributes_written, :extended_attributes_skipped, :cleanup_deleted_file, :cleanup_deleted_directory, :exported_album, :report_id, :sidecar_user, :sidecar_user_error, :user_written, :user_skipped, :user_error, :aae_written, :aae_skipped);"  # noqa
+    )
+
     def __init__(
         self, output_file: Union[str, bytes, os.PathLike], append: bool = False
     ):
@@ -202,27 +217,38 @@ class ExportReportWriterSQLite(ReportWriterABC):
         )
         self._create_tables()
         self.report_id = self._generate_report_id()
+        self._write_buffer: list[dict[str, Any]] = []
 
     def write(self, export_results: ExportResults):
-        """Write results to the output file"""
+        """Write results to a buffer; commits in batches for better performance"""
 
         all_results = prepare_export_results_for_writing(export_results)
         for data in list(all_results.values()):
             data["report_id"] = self.report_id
-            cursor = self._conn.cursor()
-            cursor.execute(
-                "INSERT INTO report "
-                "(datetime, filename, exported, new, updated, skipped, exif_updated, touched, converted_to_jpeg, sidecar_xmp, sidecar_json, sidecar_exiftool, missing, error, exiftool_warning, exiftool_error, extended_attributes_written, extended_attributes_skipped, cleanup_deleted_file, cleanup_deleted_directory, exported_album, report_id, sidecar_user, sidecar_user_error, user_written, user_skipped, user_error, aae_written, aae_skipped) "  # noqa
-                "VALUES "
-                "(:datetime, :filename, :exported, :new, :updated, :skipped, :exif_updated, :touched, :converted_to_jpeg, :sidecar_xmp, :sidecar_json, :sidecar_exiftool, :missing, :error, :exiftool_warning, :exiftool_error, :extended_attributes_written, :extended_attributes_skipped, :cleanup_deleted_file, :cleanup_deleted_directory, :exported_album, :report_id, :sidecar_user, :sidecar_user_error, :user_written, :user_skipped, :user_error, :aae_written, :aae_skipped);",  # noqa
-                data,
-            )
+            self._write_buffer.append(data)
+
+        if len(self._write_buffer) >= self.BATCH_SIZE:
+            self._flush()
+
+    def _flush(self):
+        """Flush buffered writes to database"""
+        if not self._write_buffer:
+            return
+        cursor = self._conn.cursor()
+        cursor.executemany(self._INSERT_SQL, self._write_buffer)
         self._conn.commit()
+        self._write_buffer.clear()
 
     def close(self):
-        """Close the output file"""
+        """Flush any remaining buffered writes and close the database connection"""
+        self._flush()
         self._conn.close()
 
+    def __del__(self):
+        with suppress(Exception):
+            self._flush()
+            self._conn.close()
+
     def _create_tables(self):
         c = self._conn.cursor()
         c.execute(
@@ -365,7 +391,7 @@ class ExportReportWriterSQLite(ReportWriterABC):
 
 def prepare_export_results_for_writing(
     export_results: ExportResults, bool_values: bool = False
-) -> Dict:
+) -> dict[str, dict[str, Any]]:
     """Return all results for writing to report
 
     Args:
@@ -373,7 +399,7 @@ def prepare_export_results_for_writing(
         bool_values: Return a boolean value instead of a integer (e.g. for use with JSON)
 
     Returns:
-        Dict: All results
+        dict: All results
     """
     false = False if bool_values else 0
     true = True if bool_values else 1
@@ -415,6 +441,7 @@ def prepare_export_results_for_writing(
                 "user_error": "",
                 "aae_written": false,
                 "aae_skipped": false,
+                "uuid": export_results.uuids.get(str(result), ""),
             }
 
     for result in export_results.exported:
